==> nextcloud-21.0.8p0.tgz: nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "RAM info not available" : "RAM情報が利用不可",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Links" : "リンク",
    "Emails" : "メール",
    "Federated sent" : "統合送信",
    "Federated received" : "統合受信",
    "Talk conversations" : "会話",
    "24 hours" : "24時間",
    "1 hour" : "1時間",
    "5 mins" : "5分",
    "Copy" : "コピー",
    "Copied!" : "コピー完了",
    "Not supported!" : "対応していません！",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "System" : "システム",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "Operating System" : "オペレーティングシステム",
    "CPU" : "CPU",
    "Unknown Processor" : "不明なプロセッサー",
    "Memory" : "メモリ",
    "Server time" : "サーバー時刻",
    "Uptime" : "稼働時間",
    "Load" : "負荷",
    "Disk" : "ディスク",
    "Mount" : "マウント",
    "Filesystem" : "ファイルシステム",
    "Size" : "サイズ",
    "Available" : "利用可能",
    "Used" : "使用中",
    "You will get a notification once one of your disks is nearly full." : "いずれかのディスクがいっぱいになると通知を受け取ります。",
    "Files" : "ファイル",
    "Storages" : "ストレージ",
    "Free Space" : "空き容量",
    "Network" : "ネットワーク",
    "Hostname" : "ホスト名",
    "DNS" : "DNS",
    "Gateway" : "ゲートウェイ",
    "Status" : "ステータス",
    "Speed" : "スピード",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "アクティブユーザー数",
    "Total users" : "総ユーザー数",
    "Shares" : "共有数",
    "PHP" : "PHP",
    "Version" : "バージョン",
    "Memory limit" : "メモリ制限",
    "Max execution time" : "最大実行時間",
    "Upload max size" : "最大アップロードサイズ",
    "Database" : "データベース",
    "External monitoring tool" : "外部モニタリングツール",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "URLの最後に \"?format=json\" を追加すると、JSONの結果が得られます。",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "次に、上記のURLをクエリするときに、\"NC-Token\" ヘッダーでトークンを渡します。",
    "Load average" : "ロードアベレージ",
    "Last minute" : "直近",
    "Memory info not available" : "メモリ情報が利用できません",
    "Total" : "合計",
    "Current usage" : "現在の利用量",
    "Mails" : "メール",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Total users:" : "総ユーザー数：",
    "Version:" : "バージョン:",
    "Memory Limit:" : "メモリ制限:",
    "Max Execution Time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Type:" : "タイプ:",
    "Size:" : "サイズ:",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です："
},
"nplurals=1; plural=0;");

==> nextcloud-22.1.1.tgz: nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average" : "ロードアベレージ",
    "Last minute" : "直近",
    "Memory info not available" : "メモリ情報が利用できません",
    "Total" : "合計",
    "Current usage" : "現在の利用量",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Links" : "リンク",
    "Mails" : "メール",
    "Federated sent" : "統合送信",
    "Federated received" : "統合受信",
    "Talk conversations" : "会話",
    "24 hours" : "24時間",
    "1 hour" : "1時間",
    "5 mins" : "5分",
    "Copy" : "コピー",
    "Copied!" : "コピー完了",
    "Not supported!" : "対応していません！",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "System" : "システム",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "Operating System" : "オペレーティングシステム",
    "CPU" : "CPU",
    "Memory" : "メモリ",
    "Server time" : "サーバー時刻",
    "Uptime" : "稼働時間",
    "Load" : "負荷",
    "Disk" : "ディスク",
    "Mount" : "マウント",
    "Filesystem" : "ファイルシステム",
    "Size" : "サイズ",
    "Available" : "利用可能",
    "Used" : "使用中",
    "You will get a notification once one of your disks is nearly full." : "いずれかのディスクがいっぱいになると通知を受け取ります。",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Network" : "ネットワーク",
    "Hostname" : "ホスト名",
    "DNS" : "DNS",
    "Gateway" : "ゲートウェイ",
    "Status" : "ステータス",
    "Speed" : "スピード",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "アクティブユーザー数",
    "Total users:" : "総ユーザー数：",
    "Shares" : "共有数",
    "PHP" : "PHP",
    "Version:" : "バージョン:",
    "Memory Limit:" : "メモリ制限:",
    "Max Execution Time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "Size:" : "サイズ:",
    "External monitoring tool" : "外部モニタリングツール",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です：",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "URLの最後に \"?format=json\" を追加すると、JSONの結果が得られます。",
    "To use an access token please generate one then set it using the following command:" : "アクセストークンを使用するには、トークンを生成してから、次のコマンドを使用して設定してください:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "次に、上記のURLをクエリするときに、\"NC-Token\" ヘッダーでトークンを渡します。",
    "Time Servers" : "タイムサーバー"
},
"nplurals=1; plural=0;");
